Returns number of cores used by BART
Value
Number of cores currently being used by parallelized BART functions.
Details
Returns the number of cores currently being used by parallelized BART functions
Author
Adam Kapelner and Justin Bleich
Examples
if (FALSE) { # \dontrun{
bart_machine_num_cores()
} # }