benchmark_datasets: benchmark_datasets

benchmark_datasetsR Documentation

benchmark_datasets

Description

Nine diverse datasets which were used for benchmarking bartMachine's out of sample performance in the vignette for this package.

Usage

data(benchmark_datasets)

See vignette for details.


bartMachine documentation built on May 4, 2026, 9:10 a.m.