Generates credible intervals for \(\hat{f}(x)\) for a specified set of observations.
Value
Returns a matrix of the lower and upper bounds of the credible intervals for each observation in new_data.
Details
This interval is the appropriate quantiles based on the confidence level, ci_conf, of the predictions
for each of the Gibbs samples post-burn in.
Note
This function is parallelized by the number of cores set in set_bart_machine_num_cores.
Examples
if (FALSE) { # \dontrun{
#generate Friedman data
set.seed(11)
n = 200
p = 5
X = data.frame(matrix(runif(n * p), ncol = p))
y = 10 * sin(pi* X[ ,1] * X[,2]) +20 * (X[,3] -.5)^2 + 10 * X[ ,4] + 5 * X[,5] + rnorm(n)
##build BART regression model
bart_machine = bartMachine(X, y)
#get credible interval
cred_int = calc_credible_intervals(bart_machine, X)
print(head(cred_int))
} # }