Create a data frame with factors converted to dummies.
Arguments
- data
Data frame to be dummified.
Value
Returns a data frame with factors converted to dummy indicator variables.
Details
The column names of the dummy variables are given by the “FactorName_LevelName” and are augmented to the end of the design matrix. See the example below.
Note
BART handles dummification internally. This function is provided as a utility function.
Author
Adam Kapelner and Justin Bleich